package com.aucma.report.service;

import java.util.List;
import com.aucma.report.domain.RecordSwitchOrder;

/**
 * 切换订单管理Service接口
 * 
 * @author Yinq
 * @date 2024-04-23
 */
public interface IRecordSwitchOrderService 
{
    /**
     * 查询切换订单管理
     * 
     * @param objId 切换订单管理主键
     * @return 切换订单管理
     */
    public RecordSwitchOrder selectRecordSwitchOrderByObjId(Long objId);

    /**
     * 查询切换订单管理列表
     * 
     * @param recordSwitchOrder 切换订单管理
     * @return 切换订单管理集合
     */
    public List<RecordSwitchOrder> selectRecordSwitchOrderList(RecordSwitchOrder recordSwitchOrder);

    /**
     * 新增切换订单管理
     * 
     * @param recordSwitchOrder 切换订单管理
     * @return 结果
     */
    public int insertRecordSwitchOrder(RecordSwitchOrder recordSwitchOrder);

    /**
     * 修改切换订单管理
     * 
     * @param recordSwitchOrder 切换订单管理
     * @return 结果
     */
    public int updateRecordSwitchOrder(RecordSwitchOrder recordSwitchOrder);

    /**
     * 批量删除切换订单管理
     * 
     * @param objIds 需要删除的切换订单管理主键集合
     * @return 结果
     */
    public int deleteRecordSwitchOrderByObjIds(Long[] objIds);

    /**
     * 删除切换订单管理信息
     * 
     * @param objId 切换订单管理主键
     * @return 结果
     */
    public int deleteRecordSwitchOrderByObjId(Long objId);
}
