package com.aucma.report.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.report.domain.RecordSwitchOrder;
import com.aucma.report.service.IRecordSwitchOrderService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 切换订单管理Controller
 *
 * @author Yinq
 * @date 2024-04-23
 */
@RestController
@RequestMapping("/report/switchOrder")
public class RecordSwitchOrderController extends BaseController {
    @Autowired
    private IRecordSwitchOrderService recordSwitchOrderService;

    /**
     * 查询切换订单管理列表
     */
    @PreAuthorize("@ss.hasPermi('report:switchOrder:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecordSwitchOrder recordSwitchOrder) {
        startPage();
        List<RecordSwitchOrder> list = recordSwitchOrderService.selectRecordSwitchOrderList(recordSwitchOrder);
        return getDataTable(list);
    }

    /**
     * 导出切换订单管理列表
     */
    @PreAuthorize("@ss.hasPermi('report:switchOrder:export')")
    @Log(title = "切换订单管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecordSwitchOrder recordSwitchOrder) {
        List<RecordSwitchOrder> list = recordSwitchOrderService.selectRecordSwitchOrderList(recordSwitchOrder);
        ExcelUtil<RecordSwitchOrder> util = new ExcelUtil<RecordSwitchOrder>(RecordSwitchOrder.class);
        util.exportExcel(response, list, "切换订单管理数据");
    }

    /**
     * 获取切换订单管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('report:switchOrder:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(recordSwitchOrderService.selectRecordSwitchOrderByObjId(objId));
    }

    /**
     * 新增切换订单管理
     */
    @PreAuthorize("@ss.hasPermi('report:switchOrder:add')")
    @Log(title = "切换订单管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordSwitchOrder recordSwitchOrder) {
        return toAjax(recordSwitchOrderService.insertRecordSwitchOrder(recordSwitchOrder));
    }

    /**
     * 修改切换订单管理
     */
    @PreAuthorize("@ss.hasPermi('report:switchOrder:edit')")
    @Log(title = "切换订单管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordSwitchOrder recordSwitchOrder) {
        return toAjax(recordSwitchOrderService.updateRecordSwitchOrder(recordSwitchOrder));
    }

    /**
     * 删除切换订单管理
     */
    @PreAuthorize("@ss.hasPermi('report:switchOrder:remove')")
    @Log(title = "切换订单管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(recordSwitchOrderService.deleteRecordSwitchOrderByObjIds(objIds));
    }
}
